@@ -492,4 +492,8 @@ class CGUWorkerSet(WS):
         os.rename(fname + '.tmp', fname)
         save_name = fname + ".{}".format(self.num_updates)
         copy2(fname, save_name)
-        return save_name
\ No newline at end of file
+        return save_name
+
+    def update_workers(self):
+        """Return update workers"""
+        return self
\ No newline at end of file
